==> qtjambi-debuginfo-macos-5.15.19.jar: sources/QtJambiCore/QLoggingCategory_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtCore/qloggingcategory.h>
#include <QtCore/QVariant>
#include <QtCore/qlogging.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QLoggingCategory(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QLoggingCategory")
    QLoggingCategory *_ptr = reinterpret_cast<QLoggingCategory *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QLoggingCategory(const char*)
void __qt_construct_QLoggingCategory_const_char_ptr(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QLoggingCategory(const char*)")
    jobject category0 = __java_arguments[0].l;
    QByteArray* _byte___qt_category0 = qtjambi_cast<QByteArray*>(__jni_env, category0);
    const char* __qt_category0 = _byte___qt_category0 ? _byte___qt_category0->data() : nullptr;
    QLoggingCategory *__qt_this = new(__qtjambi_ptr) QLoggingCategory(__qt_category0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QLoggingCategory::QLoggingCategory(const char*)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QLoggingCategory_initialize_1native__Lio_qt_core_QLoggingCategory_2Lio_qt_core_QByteArray_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject category0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QLoggingCategory::QLoggingCategory(const char*)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = category0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QLoggingCategory_const_char_ptr, sizeof(QLoggingCategory), typeid(QLoggingCategory), false, &deleter_QLoggingCategory, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QLoggingCategory(const char*,QtMsgType)
void __qt_construct_QLoggingCategory_const_char_ptr_QtMsgType(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QLoggingCategory(const char*,QtMsgType)")
    jobject category0 = __java_arguments[0].l;
    QByteArray* _byte___qt_category0 = qtjambi_cast<QByteArray*>(__jni_env, category0);
    const char* __qt_category0 = _byte___qt_category0 ? _byte___qt_category0->data() : nullptr;
    jobject severityLevel1 = __java_arguments[1].l;
    QtMsgType __qt_severityLevel1 = qtjambi_cast<QtMsgType>(__jni_env, severityLevel1);
    QLoggingCategory *__qt_this = new(__qtjambi_ptr) QLoggingCategory(__qt_category0, QtMsgType(__qt_severityLevel1));
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QLoggingCategory::QLoggingCategory(const char*,QtMsgType)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QLoggingCategory_initialize_1native__Lio_qt_core_QLoggingCategory_2Lio_qt_core_QByteArray_2Lio_qt_core_QtMsgType_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject category0,
 jobject severityLevel1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QLoggingCategory::QLoggingCategory(const char*,QtMsgType)")
    QTJAMBI_TRY {
        jvalue arguments[2];
        arguments[0].l = category0;
        arguments[1].l = severityLevel1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QLoggingCategory_const_char_ptr_QtMsgType, sizeof(QLoggingCategory), typeid(QLoggingCategory), false, &deleter_QLoggingCategory, arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QLoggingCategory
void __qt_destruct_QLoggingCategory(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QLoggingCategory")
    reinterpret_cast<QLoggingCategory*>(ptr)->~QLoggingCategory();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QLoggingCategory::categoryName()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QLoggingCategory_categoryName_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QLoggingCategory *__qt_this = QtJambiAPI::objectFromNativeId<QLoggingCategory>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QLoggingCategory::categoryName()const", __qt_this)
        const char* __qt_return_value = __qt_this->categoryName();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QLoggingCategory::isCriticalEnabled()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QLoggingCategory_isCriticalEnabled_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QLoggingCategory *__qt_this = QtJambiAPI::objectFromNativeId<QLoggingCategory>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QLoggingCategory::isCriticalEnabled()const", __qt_this)
        __java_return_value = __qt_this->isCriticalEnabled();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QLoggingCategory::isDebugEnabled()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QLoggingCategory_isDebugEnabled_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QLoggingCategory *__qt_this = QtJambiAPI::objectFromNativeId<QLoggingCategory>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QLoggingCategory::isDebugEnabled()const", __qt_this)
        __java_return_value = __qt_this->isDebugEnabled();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QLoggingCategory::isEnabled(QtMsgType)const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QLoggingCategory_isEnabled_1native_1QtMsgType_1constfct__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint type0)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QLoggingCategory *__qt_this = QtJambiAPI::objectFromNativeId<QLoggingCategory>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QLoggingCategory::isEnabled(QtMsgType)const", __qt_this)
        QtMsgType __qt_type0 = qtjambi_cast<QtMsgType>(__jni_env, type0);
        __java_return_value = __qt_this->isEnabled(QtMsgType(__qt_type0));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QLoggingCategory::isInfoEnabled()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QLoggingCategory_isInfoEnabled_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QLoggingCategory *__qt_this = QtJambiAPI::objectFromNativeId<QLoggingCategory>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QLoggingCategory::isInfoEnabled()const", __qt_this)
        __java_return_value = __qt_this->isInfoEnabled();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QLoggingCategory::isWarningEnabled()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QLoggingCategory_isWarningEnabled_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QLoggingCategory *__qt_this = QtJambiAPI::objectFromNativeId<QLoggingCategory>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QLoggingCategory::isWarningEnabled()const", __qt_this)
        __java_return_value = __qt_this->isWarningEnabled();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QLoggingCategory::setEnabled(QtMsgType,bool)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QLoggingCategory_setEnabled_1native_1QtMsgType_1bool__JIZ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint type0,
 jboolean enable1)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QLoggingCategory *__qt_this = QtJambiAPI::objectFromNativeId<QLoggingCategory>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QLoggingCategory::setEnabled(QtMsgType,bool)", __qt_this)
        QtMsgType __qt_type0 = qtjambi_cast<QtMsgType>(__jni_env, type0);
        __qt_this->setEnabled(QtMsgType(__qt_type0), static_cast<bool>(enable1));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QLoggingCategory::defaultCategory()
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QLoggingCategory_defaultCategory__)
(JNIEnv *__jni_env,
 jclass)
{
    QTJAMBI_NATIVE_METHOD_CALL("QLoggingCategory::defaultCategory()")
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        QLoggingCategory* __qt_return_value = QLoggingCategory::defaultCategory();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QLoggingCategory::installFilter(QLoggingCategory::CategoryFilter)
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QLoggingCategory_installFilter__Lio_qt_core_QLoggingCategory_00024CategoryFilter_2)
(JNIEnv *__jni_env,
 jclass,
 jobject arg__1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QLoggingCategory::installFilter(QLoggingCategory::CategoryFilter)")
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        QLoggingCategory::CategoryFilter __qt_arg__1 = qtjambi_cast<QLoggingCategory::CategoryFilter>(__jni_env, arg__1);
        QLoggingCategory::CategoryFilter __qt_return_value = QLoggingCategory::installFilter(__qt_arg__1);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value, "QLoggingCategory::CategoryFilter");
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QLoggingCategory::setFilterRules(QString)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QLoggingCategory_setFilterRules__Ljava_lang_String_2)
(JNIEnv *__jni_env,
 jclass,
 jstring rules0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QLoggingCategory::setFilterRules(QString)")
    QTJAMBI_TRY {
        QString  __qt_rules0 = qtjambi_cast<QString>(__jni_env, rules0);
        QLoggingCategory::setFilterRules(__qt_rules0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QLoggingCategory(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QLoggingCategory>("QLoggingCategory", "io/qt/core/QLoggingCategory");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QLoggingCategory, {
        ConstructorInfo(&__qt_construct_QLoggingCategory_const_char_ptr, "Lio/qt/core/QByteArray;")
       ,ConstructorInfo(&__qt_construct_QLoggingCategory_const_char_ptr_QtMsgType, "Lio/qt/core/QByteArray;Lio/qt/core/QtMsgType;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QLoggingCategory);
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-debuginfo-macos-6.7.2.jar: sources/QtJambiCore/QLoggingCategory_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtCore/qloggingcategory.h>
#include <QtCore/QVariant>
#include <QtCore/qlogging.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QLoggingCategory(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QLoggingCategory")
    QLoggingCategory *_ptr = reinterpret_cast<QLoggingCategory *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QLoggingCategory(const char*,QtMsgType)
void __qt_construct_QLoggingCategory_const_char_ptr(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QLoggingCategory(const char*,QtMsgType)")
    jobject category0 = __java_arguments[0].l;
    QByteArray* _byte___qt_category0 = qtjambi_cast<QByteArray*>(__jni_env, category0);
    const char* __qt_category0 = _byte___qt_category0 ? _byte___qt_category0->data() : nullptr;
    QLoggingCategory *__qt_this = new(__qtjambi_ptr) QLoggingCategory(__qt_category0);
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
}

// new QLoggingCategory(const char*,QtMsgType)
void __qt_construct_QLoggingCategory_const_char_ptr_QtMsgType(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QLoggingCategory(const char*,QtMsgType)")
    jobject category0 = __java_arguments[0].l;
    QByteArray* _byte___qt_category0 = qtjambi_cast<QByteArray*>(__jni_env, category0);
    const char* __qt_category0 = _byte___qt_category0 ? _byte___qt_category0->data() : nullptr;
    jobject severityLevel1 = __java_arguments[1].l;
    QtMsgType __qt_severityLevel1 = qtjambi_cast<QtMsgType>(__jni_env, severityLevel1);
    QLoggingCategory *__qt_this = new(__qtjambi_ptr) QLoggingCategory(__qt_category0, QtMsgType(__qt_severityLevel1));
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
}

// QLoggingCategory::QLoggingCategory(const char*,QtMsgType)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QLoggingCategory_initialize_1native__Lio_qt_core_QLoggingCategory_2Lio_qt_core_QByteArray_2Lio_qt_core_QtMsgType_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject category0,
 jobject severityLevel1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QLoggingCategory::QLoggingCategory(const char*,QtMsgType)")
    QTJAMBI_TRY {
        jvalue arguments[2];
        arguments[0].l = category0;
        arguments[1].l = severityLevel1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QLoggingCategory_const_char_ptr_QtMsgType, sizeof(QLoggingCategory), typeid(QLoggingCategory), 0, false, &deleter_QLoggingCategory, arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QLoggingCategory
void __qt_destruct_QLoggingCategory(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QLoggingCategory")
    reinterpret_cast<QLoggingCategory*>(ptr)->~QLoggingCategory();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QLoggingCategory::categoryName()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QLoggingCategory_categoryName_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QLoggingCategory *__qt_this = QtJambiAPI::objectFromNativeId<QLoggingCategory>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QLoggingCategory::categoryName()const", __this_nativeId)
        const char* __qt_return_value = __qt_this->categoryName();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QLoggingCategory::isCriticalEnabled()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QLoggingCategory_isCriticalEnabled_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QLoggingCategory *__qt_this = QtJambiAPI::objectFromNativeId<QLoggingCategory>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QLoggingCategory::isCriticalEnabled()const", __this_nativeId)
        __java_return_value = __qt_this->isCriticalEnabled();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QLoggingCategory::isDebugEnabled()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QLoggingCategory_isDebugEnabled_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QLoggingCategory *__qt_this = QtJambiAPI::objectFromNativeId<QLoggingCategory>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QLoggingCategory::isDebugEnabled()const", __this_nativeId)
        __java_return_value = __qt_this->isDebugEnabled();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QLoggingCategory::isEnabled(QtMsgType)const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QLoggingCategory_isEnabled_1native_1QtMsgType_1constfct__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint type0)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QLoggingCategory *__qt_this = QtJambiAPI::objectFromNativeId<QLoggingCategory>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QLoggingCategory::isEnabled(QtMsgType)const", __this_nativeId)
        QtMsgType __qt_type0 = qtjambi_cast<QtMsgType>(__jni_env, type0);
        __java_return_value = __qt_this->isEnabled(QtMsgType(__qt_type0));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QLoggingCategory::isInfoEnabled()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QLoggingCategory_isInfoEnabled_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QLoggingCategory *__qt_this = QtJambiAPI::objectFromNativeId<QLoggingCategory>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QLoggingCategory::isInfoEnabled()const", __this_nativeId)
        __java_return_value = __qt_this->isInfoEnabled();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QLoggingCategory::isWarningEnabled()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QLoggingCategory_isWarningEnabled_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QLoggingCategory *__qt_this = QtJambiAPI::objectFromNativeId<QLoggingCategory>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QLoggingCategory::isWarningEnabled()const", __this_nativeId)
        __java_return_value = __qt_this->isWarningEnabled();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QLoggingCategory::setEnabled(QtMsgType,bool)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QLoggingCategory_setEnabled_1native_1QtMsgType_1bool__JIZ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint type0,
 jboolean enable1)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QLoggingCategory *__qt_this = QtJambiAPI::objectFromNativeId<QLoggingCategory>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QLoggingCategory::setEnabled(QtMsgType,bool)", __this_nativeId)
        QtMsgType __qt_type0 = qtjambi_cast<QtMsgType>(__jni_env, type0);
        __qt_this->setEnabled(QtMsgType(__qt_type0), static_cast<bool>(enable1));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QLoggingCategory::defaultCategory()
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QLoggingCategory_defaultCategory__)
(JNIEnv *__jni_env,
 jclass)
{
    QTJAMBI_NATIVE_METHOD_CALL("QLoggingCategory::defaultCategory()")
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        QLoggingCategory* __qt_return_value = QLoggingCategory::defaultCategory();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QLoggingCategory::installFilter(QLoggingCategory::CategoryFilter)
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QLoggingCategory_installFilter__Lio_qt_core_QLoggingCategory_00024CategoryFilter_2)
(JNIEnv *__jni_env,
 jclass,
 jobject arg__1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QLoggingCategory::installFilter(QLoggingCategory::CategoryFilter)")
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        QLoggingCategory::CategoryFilter __qt_arg__1 = qtjambi_cast<QLoggingCategory::CategoryFilter>(__jni_env, arg__1);
        QLoggingCategory::CategoryFilter __qt_return_value = QLoggingCategory::installFilter(__qt_arg__1);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value, "QLoggingCategory::CategoryFilter");
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QLoggingCategory::setFilterRules(QString)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QLoggingCategory_setFilterRules__Ljava_lang_String_2)
(JNIEnv *__jni_env,
 jclass,
 jstring rules0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QLoggingCategory::setFilterRules(QString)")
    QTJAMBI_TRY {
        QString __qt_rules0 = qtjambi_cast<QString>(__jni_env, rules0);
        QLoggingCategory::setFilterRules(__qt_rules0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QLoggingCategory(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QLoggingCategory>("QLoggingCategory", "io/qt/core/QLoggingCategory");
// BEGIN: function table
    registerConstructorInfos(typeId, 0, &__qt_destruct_QLoggingCategory, {
        ConstructorInfo(&__qt_construct_QLoggingCategory_const_char_ptr, "Lio/qt/core/QByteArray;")
       ,ConstructorInfo(&__qt_construct_QLoggingCategory_const_char_ptr_QtMsgType, "Lio/qt/core/QByteArray;Lio/qt/core/QtMsgType;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QLoggingCategory);
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
